justbases package — justbases 0.07 documentation

### Navigation

- index
- modules |
- next |
- previous |
- justbases 0.07 documentation »
- justbases »

# justbases package

## Submodules

- justbases._config module
- justbases._constants module
- justbases._display module
- justbases._division module
- justbases._errors module
- justbases._nats module
- justbases._rationals module
- justbases.version module
  - justbases.version

## Module contents

The public interface of justbases.

Contents:

> - RoundingMethods – a list of available rounding methods
> - NatDivision – long division of natural numbers and its inverse
> - BasesError – supertype of errors raised by package methods
> - Nats
>   - conversion between non-negative ints and sequences
>   - conversion between sequences in one base to sequences in another
> - Radix – representation of rational number as string of digits
> - Rationals
>   - conversion between Rational and Radix objects
>   - conversion between Radix objects in any base

### Navigation

- index
- modules |
- next |
- previous |
- justbases 0.07 documentation »
- justbases »